Plots survival functions

DESCRIPTION

This function takes a vector of survival values and a 
vector of time values and either plots  a survival
function or adds the survival lines to an existing plot.

USAGE

icplot(surv, time=as.numeric(names(surv)), xrange=NA, 
lines.only=F, XLAB="Time", YLAB="Probability", LTY=1, ...)

REQUIRED ARGUMENTS

surv      a vector of survival values. 

OPTIONAL ARGUMENTS

time     a vector of times. These are related to the 
         vector of survival by  
         Prob( X > time[i] ) = surv[i]. If this vector 
         is not given then the default is to use 
         as.numeric(names(surv)).

xrange   the range of the x values. The default is 
         c(0,max(time[time<Inf])). This value may need 
         to be supplied when plotting more than one 
         survival curve on a single plot 
         (see lines.only).

lines.only
       a logical value; default = F. If lines.only=F 
       the function draws a new set of axes. If 
       lines.only=T the function adds  lines to
       an existing plot.  To print 2 lines on one 
       plot, call the function twice, the first time 
       with lines.only=F and xrange=range(c(t1,t2))
       where t1 and t2 are the (finite) times for the 
       two survival curves, the second time with 
       lines.only=T.

XLAB    a character string denoting the x label. 
        Default="Time".

YLAB    a character string denoting the y label. 
        Default="Probability".

LTY     an integer denoting the line type (lty value).

...    added plotting parameters (except xlab and ylab).              

VALUE 
   Returns a plot or adds a line to an existing plot.

DETAILS
   See icfit details. This may not be the most accurate 
   way to present the data. See Betensky, Lindsey, Ryan,
   and Wand (1999, p. 238) for an alternative method. 

REFERENCES
   Betensky RA, Lindsey JC, Ryan LM, Wand MP (1999).
   "Local EM Estimation of the Hazard Function for 
   Interval-Censored Data", Biometrics, 55: 238-245.

SEE ALSO 
   icfit, ictest

EXAMPLE
   ### Plot two Survival curves on one plot
   s1<- icfit(left[treatment==1],right[treatment==1])
   s2<- icfit(left[treatment==2],right[treatment==2])
   icpot(s1$surv,s1$time,
          xrange=range(c(s1$time,s2$time)))
   icplot(s2$surv,s2$time,lines.only=T,LTY=2)